@@ -11,14 +11,7 @@ query_list_to_tibble <- function(x, timestamp_format) {
   timer <- function(x, txt) {message(paste(Sys.time(), txt));x}
   
   # create divisor for different timestamp format
-  div <- switch(timestamp_format,
-                "n" = 1e+9,
-                "u" = 1e+6,
-                "ms" = 1e+3,
-                "s" = 1,
-                "m" = 1 / 60,
-                "h" = 1 / (60 * 60)
-  )
+  div <- get_precision_divisor(timestamp_format)
   
   # set default result
   result_na <- tibble::tibble(statement_id = NA,
@@ -44,6 +37,9 @@ query_list_to_tibble <- function(x, timestamp_format) {
     if (!is.null(series_ele$statement_id)) {
       # extract "statement_id"
       statement_id <- series_ele$statement_id
+    } else {
+      # set NA to statement_id if not found
+      statement_id <- NA_integer_
     }
       
     if (!is.null(series_ele$series)) {
@@ -132,6 +128,7 @@ query_list_to_tibble <- function(x, timestamp_format) {
     rle %>% # perform run length encoding to get the length of each "statement_id"
     rle_seq_to_list %>% # own function to make a list of sequences from rle
     purrr::map( ~ dplyr::bind_rows(list_of_result[.])) # rbind results
+  
     
   # return list of tibbles
   return(list_of_result)
@@ -217,7 +214,7 @@ tibble_to_xts <- function(x) {
     # select all "tagkey" columns
     dplyr::select(statement_id:time,-time) %>%
     # create a group index
-    dplyr::group_indices_(.dots = colnames(.)) %>%
+    dplyr::group_indices(!!!rlang::syms(colnames(.))) %>%
     # add group index to tibble
     dplyr::mutate(x, grp_idx = .) %>%
     # create list of tibble by group
